import { SafeString } from 'handlebars';
import { oneLine } from 'common-tags';
function blockComment(str) {
    if (!str || str === '') {
        return '';
    }
    return new SafeString([
        '\n',
        '// ====================================================',
        '// ' + oneLine `${str || ''}`,
        '// ====================================================',
        '\n'
    ].join('\n'));
}
export const helpers = {
    for(from, to, incr, block) {
        let accum = '';
        for (let i = from; i < to; i += incr) {
            accum += block.fn(i);
        }
        return accum;
    },
    ifCond(v1, operator, v2, options) {
        switch (operator) {
            case '==':
                return v1 === v2 ? options.fn(this) : options.inverse(this);
            case '===':
                return v1 === v2 ? options.fn(this) : options.inverse(this);
            case '!=':
                return v1 !== v2 ? options.fn(this) : options.inverse(this);
            case '!==':
                return v1 !== v2 ? options.fn(this) : options.inverse(this);
            case '<':
                return v1 < v2 ? options.fn(this) : options.inverse(this);
            case '<=':
                return v1 <= v2 ? options.fn(this) : options.inverse(this);
            case '>':
                return v1 > v2 ? options.fn(this) : options.inverse(this);
            case '>=':
                return v1 >= v2 ? options.fn(this) : options.inverse(this);
            case '&&':
                return v1 && v2 ? options.fn(this) : options.inverse(this);
            case '||':
                return v1 || v2 ? options.fn(this) : options.inverse(this);
            default:
                return options.inverse(this);
        }
    },
    toScalar: (scalars) => (type) => {
        return scalars[type] || type || '';
    },
    blockCommentIf(str, list = []) {
        if (list && list.length > 0) {
            return blockComment(str);
        }
        return '';
    },
    blockComment,
    toComment(str) {
        if (!str || str === '') {
            return '';
        }
        return new SafeString('/** ' + oneLine `${str || ''}` + ' */');
    },
    toLowerCase(str) {
        return (str || '').toLowerCase();
    },
    toUpperCase(str) {
        return (str || '').toUpperCase();
    },
    stringify(obj) {
        return new SafeString(JSON.stringify(obj));
    },
    times(n, block) {
        let accum = '';
        for (let i = 0; i < n; ++i) {
            accum += block.fn(i);
        }
        return accum;
    },
    ifDirective(context, directiveName, options) {
        if (context && context['directives'] && directiveName && typeof directiveName === 'string') {
            const directives = context['directives'];
            const directiveValue = directives[directiveName];
            if (directiveValue) {
                return options && options.fn ? options.fn(Object.assign({}, (directiveValue || {}), context)) : '';
            }
            else {
                return options && options.inverse ? options.inverse(context) : '';
            }
        }
        return options && options.inverse ? options.inverse(context) : '';
    },
    unlessDirective(context, directiveName, options) {
        if (context && context['directives'] && directiveName && typeof directiveName === 'string') {
            const directives = context['directives'];
            const directiveValue = directives[directiveName];
            if (!directiveValue) {
                return options && options.fn ? options.fn(Object.assign({}, (directiveValue || {}), context)) : '';
            }
            else {
                return options && options.inverse ? options.inverse(context) : '';
            }
        }
        return options && options.inverse ? options.inverse(context) : '';
    }
};
//# sourceMappingURL=index.js.map